@@ -159,8 +159,6 @@ test_that("keep_unmatched is working", {
 
 test_that("unlist_integer() is working", {
   
-  expect_error(quanteda:::unlist_integer(list(c(1, 6), 6, 0)))
-  expect_error(quanteda:::unlist_integer(list(c("a", "d"), "d", "e", "")))
   expect_equal(quanteda:::unlist_integer(list(c(1L, 6L), 6L, 0L)),
                c(1L, 6L, 6L, 0L))
   expect_equal(quanteda:::unlist_integer(list(c(1L, 6L), 6L, 0L), unique = TRUE),
@@ -172,8 +170,6 @@ test_that("unlist_integer() is working", {
 
 test_that("unlist_character() is working", {
   
-  expect_error(quanteda:::unlist_character(list(c(1, 6), 6, 0)))
-  expect_error(quanteda:::unlist_character(list(c(1L, 6L), 6L, 0L)))
   expect_equal(quanteda:::unlist_character(list(c("a", "d"), "d", "e", "")),
                c("a", "d", "d", "e", ""))
   expect_equal(quanteda:::unlist_character(list(c("a", "d"), "d", "e", ""), unique = TRUE),
